@@ -55,14 +55,17 @@ class AdbExt(object):
 
     def screenshot(self, pc_path=None, pil_image=True, is_jpg=False, quality=65):
         if pc_path:
+            if self.util.is_py2:
+                pc_path = pc_path.decode('utf-8')
+            self.delete_from_pc(pc_path)  # 删除电脑文件
+
             _, ext = os.path.splitext(pc_path)
             folder_path, _ = os.path.split(pc_path)
-            if not os.path.isdir(folder_path):
+            if folder_path and not os.path.isdir(folder_path):
                 os.makedirs(folder_path)
 
             if ext.lower() in ['.jpg', '.jpeg']:  # 根据后缀判断格式
                 is_jpg = True
-            self.delete_from_pc(pc_path)  # 删除电脑文件
 
         arg = 'adb -s {} exec-out screencap -p'.format(self.util.sn)
         image = self.util.cmd(arg, is_bytes=True)  # 这里是 png str
